/**
 * @(#)BarClient.java 1.0
 * @Author Tognon Stefano 1.0 (1998) all the work
 *
 * This software was developing at Padova University in collaboration with
 * Padova CNR Ladseb in Italy.
 * THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND.
 * 
 * This program creates (the server and) the client that are able to perform 
 * a robots cooperative bar pushing task using behavior based agents control.
 * See the "Tognon Stefano, Trasporto collettivo di oggetti tramite robot mobili,
 * Tesi di Laurea, Universit degli Studi di Padova, Marzo 1999"
 * for more details.
 */

package simulator;

import simulator.*;
import java.awt.*;
import java.awt.event.*;
import java.lang.*;
import java.util.*;

/**
 * Create the client for Bar Pushing simulation ambient
 */
public class BarClient extends Client {
 
  /**
   * Label for box mass text
   */
  Label boxMassLabel;   

  /**
   * Label for box dimension text
   */
  Label boxDimLabel;

  /**
   * Label for bar length text
   */
  Label barLengthLabel;

  /**
   * Area for input box mass
   */
  TextField boxMassText;

  /**
   * Area for input box dimension
   */
  TextField boxDimText;
  
  /**
   * Area for input bar length
   */
  TextField barLengthText;

  /**
   * Initialize the client
   */
  public void init() {
    about="\n Virtual Lab Client \n for Bar pushing";
    super.init();
  }

  public void stop() { 
    super.stop();
  }

public void graphAppletInitAWT1_0() {
    // create a label for box mass
    boxMassLabel=new Label("Box mass (Kg):");
    boxMassLabel.setAlignment(Label.CENTER);
    boxMassLabel.reshape(505, 10, 80, 30); 
    add(boxMassLabel);

    //create a text field for box mass
    boxMassText=new TextField(String.valueOf(Fisical.boxMass),20);
    boxMassText.reshape(505, 35, 80, 30);
    add(boxMassText);

    // create a label for box dimension
    boxDimLabel=new Label("Box dim. (cm):");
    boxDimLabel.setAlignment(Label.CENTER);
    boxDimLabel.reshape(505, 55, 80, 30); 
    add(boxDimLabel);

    //create a text field for box mass
    boxDimText=new TextField(String.valueOf(Fisical.boxDim*100),20);
    boxDimText.reshape(505, 80, 80, 30);
    add(boxDimText);
 

    // create a label for bar length
    barLengthLabel=new Label("Bar Length (m):");
    barLengthLabel.setAlignment(Label.CENTER);
    barLengthLabel.reshape(505, 100, 80, 30); 
    add(barLengthLabel);

    //create a text field for box mass
    barLengthText=new TextField(String.valueOf(Fisical.barLength),20);
    barLengthText.reshape(505, 125, 80, 23);
    add(barLengthText);
  }

  /**
   * Create the applet graphics component
   * We determine if the browser we use is an AWT 1.0 or 1.1 and so use the
   * appropriate methods.
   * 
   */
  public void graphAppletInit() {
    super.graphAppletInit();

    // create a label for box mass
    Label temp=new Label("Box mass (Kg):");
    // find if we have an AWT 1.1 browser
    try {
     Class[] param={};
     temp.getClass().getMethod("getBounds", param); 
    } catch (NoSuchMethodException e) {
        System.out.println("Sorry, you have AWT 1.0 Browser!");
        graphAppletInitAWT1_0(); 
        return;
      };
    Object g=new Object() {
      public void graphAppletInitAWT1_1() { 
      // create a label for box mass
        boxMassLabel=new Label("Box mass (Kg):");
        boxMassLabel.setAlignment(Label.CENTER);
        boxMassLabel.setBounds(505, 10, 80, 30); 
        add(boxMassLabel);

        //create a text field for box mass
        boxMassText=new TextField(String.valueOf(Fisical.boxMass),20);
        boxMassText.setBounds(505, 35, 80, 30);
        boxMassText.addActionListener(new ActionListener() {
          public void actionPerformed(ActionEvent e) {
            double param;
            param=new Double(boxMassText.getText()).doubleValue();
            winLocal.setText("FISICAL 1 "+param+"\n");        
          }
        }); 
        add(boxMassText);

        // create a label for box dimension
        boxDimLabel=new Label("Box dim. (cm):");
        boxDimLabel.setAlignment(Label.CENTER);
        boxDimLabel.setBounds(505, 55, 80, 30); 
        add(boxDimLabel);
 
        //create a text field for box mass
        boxDimText=new TextField(String.valueOf(Fisical.boxDim*100),20);
        boxDimText.setBounds(505, 80, 80, 30);
        boxDimText.addActionListener(new ActionListener() {
          public void actionPerformed(ActionEvent e) {
            double param; 
            param=new Double(boxDimText.getText()).doubleValue();
            winLocal.setText("FISICAL 2 "+param+"\n");        
          }
        }); 
        add(boxDimText);
 
        // create a label for bar length
        barLengthLabel=new Label("Bar Length (m):");
        barLengthLabel.setAlignment(Label.CENTER);
        barLengthLabel.setBounds(505, 100, 80, 30); 
        add(barLengthLabel);
  
        //create a text field for box mass
        barLengthText=new TextField(String.valueOf(Fisical.barLength),20);
        barLengthText.setBounds(505, 125, 80, 23);
        barLengthText.addActionListener(new ActionListener() {
          public void actionPerformed(ActionEvent e) {
            double param;
            param=new Double(barLengthText.getText()).doubleValue();
            winLocal.setText("FISICAL 3 "+param+"\n");        
          }
        }); 
        add(barLengthText);  
      }
    };
  }

  /** 
   * Redefine paint method to change text field area according with actual value
   * 
   * @param g not used
   */
  public void paint(Graphics g) {
    boxMassText.setText(String.valueOf(Fisical.boxMass));
    boxDimText.setText(String.valueOf(Fisical.boxDim*100));
    barLengthText.setText(String.valueOf(Fisical.barLength));
    super.paint(g);
  }

  /**
   * Extends basic commands: 
   * a "%% n val" string means that we have to change the value of Fisical
   * simulation costant.
   *
   * @param s the string containing the command
   */ 
  public void runCommand(String s) {
    StringTokenizer ST=new StringTokenizer(s," [],",false);
    if (ST.countTokens()>0)
      if (!ST.nextToken().equals("%%")) {
        super.runCommand(s); 
        return;
      }
    if (ST.countTokens()>=2) {
      switch ((new Integer(ST.nextToken())).intValue()) {
        case 1:
          Fisical.boxMass=(new Double(ST.nextToken())).doubleValue();         
          break;
        case 2:
          Fisical.boxDim=(new Double(ST.nextToken())).doubleValue();
          break;
        case 3:
          Fisical.barLength=(new Double(ST.nextToken())).doubleValue();
          break;
      }
    } 
  }
}

